# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['MonitorArgs', 'Monitor']

@pulumi.input_type
class MonitorArgs:
    def __init__(__self__, *,
                 status: pulumi.Input[builtins.str],
                 type: pulumi.Input[builtins.str],
                 account_id: Optional[pulumi.Input[builtins.str]] = None,
                 browsers: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 bypass_head_request: Optional[pulumi.Input[builtins.bool]] = None,
                 custom_headers: Optional[pulumi.Input[Sequence[pulumi.Input['MonitorCustomHeaderArgs']]]] = None,
                 device_orientation: Optional[pulumi.Input[builtins.str]] = None,
                 device_type: Optional[pulumi.Input[builtins.str]] = None,
                 devices: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 enable_screenshot_on_failure_and_script: Optional[pulumi.Input[builtins.bool]] = None,
                 locations_privates: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 locations_publics: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 period: Optional[pulumi.Input[builtins.str]] = None,
                 runtime_type: Optional[pulumi.Input[builtins.str]] = None,
                 runtime_type_version: Optional[pulumi.Input[builtins.str]] = None,
                 script_language: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input['MonitorTagArgs']]]] = None,
                 treat_redirect_as_failure: Optional[pulumi.Input[builtins.bool]] = None,
                 uri: Optional[pulumi.Input[builtins.str]] = None,
                 use_unsupported_legacy_runtime: Optional[pulumi.Input[builtins.bool]] = None,
                 validation_string: Optional[pulumi.Input[builtins.str]] = None,
                 verify_ssl: Optional[pulumi.Input[builtins.bool]] = None):
        """
        The set of arguments for constructing a Monitor resource.
        :param pulumi.Input[builtins.str] status: The run state of the monitor. (`ENABLED` or `DISABLED`).
        :param pulumi.Input[builtins.str] type: The monitor type. Valid values are `SIMPLE` and `BROWSER`.
        :param pulumi.Input[builtins.str] account_id: The account in which the Synthetics monitor will be created.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] browsers: The multiple browsers list on which synthetic monitors will run. Valid values are `CHROME` and `FIREFOX`.
        :param pulumi.Input[builtins.bool] bypass_head_request: Monitor should skip default HEAD request and instead use GET verb in check.
               
               The `BROWSER` monitor type supports the following additional arguments:
        :param pulumi.Input[Sequence[pulumi.Input['MonitorCustomHeaderArgs']]] custom_headers: Custom headers to use in monitor job. See Nested custom_header blocks below for details.
        :param pulumi.Input[builtins.str] device_orientation: Device emulation orientation field. Valid values are `LANDSCAPE` and `PORTRAIT`. 
               * We recommend you to use `devices` field instead of `device_type`,`device_orientation` fields, as it allows you to select multiple combinations of device types and orientations.
        :param pulumi.Input[builtins.str] device_type: Device emulation type field. Valid values are `MOBILE` and `TABLET`. 
               * We recommend you to use `devices` field instead of `device_type`,`device_orientation` fields, as it allows you to select multiple combinations of device types and orientations.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] devices: The multiple devices list on which synthetic monitors will run. Valid values are `DESKTOP`, `MOBILE_LANDSCAPE`, `MOBILE_PORTRAIT`, `TABLET_LANDSCAPE` and `TABLET_PORTRAIT`.
        :param pulumi.Input[builtins.bool] enable_screenshot_on_failure_and_script: Capture a screenshot during job execution.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] locations_privates: The location the monitor will run from. Accepts a list of private location GUIDs. At least one of either `locations_public` or `locations_private` is required.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] locations_publics: The location the monitor will run from. Check out [this page](https://docs.newrelic.com/docs/synthetics/synthetic-monitoring/administration/synthetic-public-minion-ips/) for a list of valid public locations. You don't need the `AWS_` prefix as the provider uses NerdGraph. At least one of either `locations_public` or `location_private` is required.
        :param pulumi.Input[builtins.str] name: The human-readable identifier for the monitor.
        :param pulumi.Input[builtins.str] period: The interval at which this monitor should run. Valid values are `EVERY_MINUTE`, `EVERY_5_MINUTES`, `EVERY_10_MINUTES`, `EVERY_15_MINUTES`, `EVERY_30_MINUTES`, `EVERY_HOUR`, `EVERY_6_HOURS`, `EVERY_12_HOURS`, or `EVERY_DAY`.
        :param pulumi.Input[builtins.str] runtime_type: The runtime that the monitor will use to run jobs (`CHROME_BROWSER`).
        :param pulumi.Input[builtins.str] runtime_type_version: The specific version of the runtime type selected (`100`).
        :param pulumi.Input[builtins.str] script_language: The programing language that should execute the script.
        :param pulumi.Input[Sequence[pulumi.Input['MonitorTagArgs']]] tags: The tags that will be associated with the monitor. See Nested tag blocks below for details.
               
               The `SIMPLE` monitor type supports the following additional arguments:
        :param pulumi.Input[builtins.bool] treat_redirect_as_failure: Categorize redirects during a monitor job as a failure.
        :param pulumi.Input[builtins.str] uri: The URI the monitor runs against.
        :param pulumi.Input[builtins.str] validation_string: Validation text for monitor to search for at given URI.
        :param pulumi.Input[builtins.bool] verify_ssl: Monitor should validate SSL certificate chain.
        """
        pulumi.set(__self__, "status", status)
        pulumi.set(__self__, "type", type)
        if account_id is not None:
            pulumi.set(__self__, "account_id", account_id)
        if browsers is not None:
            pulumi.set(__self__, "browsers", browsers)
        if bypass_head_request is not None:
            pulumi.set(__self__, "bypass_head_request", bypass_head_request)
        if custom_headers is not None:
            pulumi.set(__self__, "custom_headers", custom_headers)
        if device_orientation is not None:
            pulumi.set(__self__, "device_orientation", device_orientation)
        if device_type is not None:
            pulumi.set(__self__, "device_type", device_type)
        if devices is not None:
            pulumi.set(__self__, "devices", devices)
        if enable_screenshot_on_failure_and_script is not None:
            pulumi.set(__self__, "enable_screenshot_on_failure_and_script", enable_screenshot_on_failure_and_script)
        if locations_privates is not None:
            pulumi.set(__self__, "locations_privates", locations_privates)
        if locations_publics is not None:
            pulumi.set(__self__, "locations_publics", locations_publics)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if period is not None:
            pulumi.set(__self__, "period", period)
        if runtime_type is not None:
            pulumi.set(__self__, "runtime_type", runtime_type)
        if runtime_type_version is not None:
            pulumi.set(__self__, "runtime_type_version", runtime_type_version)
        if script_language is not None:
            pulumi.set(__self__, "script_language", script_language)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if treat_redirect_as_failure is not None:
            pulumi.set(__self__, "treat_redirect_as_failure", treat_redirect_as_failure)
        if uri is not None:
            pulumi.set(__self__, "uri", uri)
        if use_unsupported_legacy_runtime is not None:
            pulumi.set(__self__, "use_unsupported_legacy_runtime", use_unsupported_legacy_runtime)
        if validation_string is not None:
            pulumi.set(__self__, "validation_string", validation_string)
        if verify_ssl is not None:
            pulumi.set(__self__, "verify_ssl", verify_ssl)

    @property
    @pulumi.getter
    def status(self) -> pulumi.Input[builtins.str]:
        """
        The run state of the monitor. (`ENABLED` or `DISABLED`).
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter
    def type(self) -> pulumi.Input[builtins.str]:
        """
        The monitor type. Valid values are `SIMPLE` and `BROWSER`.
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "type", value)

    @property
    @pulumi.getter(name="accountId")
    def account_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The account in which the Synthetics monitor will be created.
        """
        return pulumi.get(self, "account_id")

    @account_id.setter
    def account_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "account_id", value)

    @property
    @pulumi.getter
    def browsers(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        The multiple browsers list on which synthetic monitors will run. Valid values are `CHROME` and `FIREFOX`.
        """
        return pulumi.get(self, "browsers")

    @browsers.setter
    def browsers(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "browsers", value)

    @property
    @pulumi.getter(name="bypassHeadRequest")
    def bypass_head_request(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Monitor should skip default HEAD request and instead use GET verb in check.

        The `BROWSER` monitor type supports the following additional arguments:
        """
        return pulumi.get(self, "bypass_head_request")

    @bypass_head_request.setter
    def bypass_head_request(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "bypass_head_request", value)

    @property
    @pulumi.getter(name="customHeaders")
    def custom_headers(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['MonitorCustomHeaderArgs']]]]:
        """
        Custom headers to use in monitor job. See Nested custom_header blocks below for details.
        """
        return pulumi.get(self, "custom_headers")

    @custom_headers.setter
    def custom_headers(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['MonitorCustomHeaderArgs']]]]):
        pulumi.set(self, "custom_headers", value)

    @property
    @pulumi.getter(name="deviceOrientation")
    def device_orientation(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Device emulation orientation field. Valid values are `LANDSCAPE` and `PORTRAIT`. 
        * We recommend you to use `devices` field instead of `device_type`,`device_orientation` fields, as it allows you to select multiple combinations of device types and orientations.
        """
        return pulumi.get(self, "device_orientation")

    @device_orientation.setter
    def device_orientation(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "device_orientation", value)

    @property
    @pulumi.getter(name="deviceType")
    def device_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Device emulation type field. Valid values are `MOBILE` and `TABLET`. 
        * We recommend you to use `devices` field instead of `device_type`,`device_orientation` fields, as it allows you to select multiple combinations of device types and orientations.
        """
        return pulumi.get(self, "device_type")

    @device_type.setter
    def device_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "device_type", value)

    @property
    @pulumi.getter
    def devices(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        The multiple devices list on which synthetic monitors will run. Valid values are `DESKTOP`, `MOBILE_LANDSCAPE`, `MOBILE_PORTRAIT`, `TABLET_LANDSCAPE` and `TABLET_PORTRAIT`.
        """
        return pulumi.get(self, "devices")

    @devices.setter
    def devices(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "devices", value)

    @property
    @pulumi.getter(name="enableScreenshotOnFailureAndScript")
    def enable_screenshot_on_failure_and_script(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Capture a screenshot during job execution.
        """
        return pulumi.get(self, "enable_screenshot_on_failure_and_script")

    @enable_screenshot_on_failure_and_script.setter
    def enable_screenshot_on_failure_and_script(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "enable_screenshot_on_failure_and_script", value)

    @property
    @pulumi.getter(name="locationsPrivates")
    def locations_privates(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        The location the monitor will run from. Accepts a list of private location GUIDs. At least one of either `locations_public` or `locations_private` is required.
        """
        return pulumi.get(self, "locations_privates")

    @locations_privates.setter
    def locations_privates(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "locations_privates", value)

    @property
    @pulumi.getter(name="locationsPublics")
    def locations_publics(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        The location the monitor will run from. Check out [this page](https://docs.newrelic.com/docs/synthetics/synthetic-monitoring/administration/synthetic-public-minion-ips/) for a list of valid public locations. You don't need the `AWS_` prefix as the provider uses NerdGraph. At least one of either `locations_public` or `location_private` is required.
        """
        return pulumi.get(self, "locations_publics")

    @locations_publics.setter
    def locations_publics(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "locations_publics", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The human-readable identifier for the monitor.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def period(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The interval at which this monitor should run. Valid values are `EVERY_MINUTE`, `EVERY_5_MINUTES`, `EVERY_10_MINUTES`, `EVERY_15_MINUTES`, `EVERY_30_MINUTES`, `EVERY_HOUR`, `EVERY_6_HOURS`, `EVERY_12_HOURS`, or `EVERY_DAY`.
        """
        return pulumi.get(self, "period")

    @period.setter
    def period(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "period", value)

    @property
    @pulumi.getter(name="runtimeType")
    def runtime_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The runtime that the monitor will use to run jobs (`CHROME_BROWSER`).
        """
        return pulumi.get(self, "runtime_type")

    @runtime_type.setter
    def runtime_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "runtime_type", value)

    @property
    @pulumi.getter(name="runtimeTypeVersion")
    def runtime_type_version(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The specific version of the runtime type selected (`100`).
        """
        return pulumi.get(self, "runtime_type_version")

    @runtime_type_version.setter
    def runtime_type_version(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "runtime_type_version", value)

    @property
    @pulumi.getter(name="scriptLanguage")
    def script_language(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The programing language that should execute the script.
        """
        return pulumi.get(self, "script_language")

    @script_language.setter
    def script_language(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "script_language", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['MonitorTagArgs']]]]:
        """
        The tags that will be associated with the monitor. See Nested tag blocks below for details.

        The `SIMPLE` monitor type supports the following additional arguments:
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['MonitorTagArgs']]]]):
        pulumi.set(self, "tags", value)

    @property
    @pulumi.getter(name="treatRedirectAsFailure")
    def treat_redirect_as_failure(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Categorize redirects during a monitor job as a failure.
        """
        return pulumi.get(self, "treat_redirect_as_failure")

    @treat_redirect_as_failure.setter
    def treat_redirect_as_failure(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "treat_redirect_as_failure", value)

    @property
    @pulumi.getter
    def uri(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The URI the monitor runs against.
        """
        return pulumi.get(self, "uri")

    @uri.setter
    def uri(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "uri", value)

    @property
    @pulumi.getter(name="useUnsupportedLegacyRuntime")
    def use_unsupported_legacy_runtime(self) -> Optional[pulumi.Input[builtins.bool]]:
        return pulumi.get(self, "use_unsupported_legacy_runtime")

    @use_unsupported_legacy_runtime.setter
    def use_unsupported_legacy_runtime(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "use_unsupported_legacy_runtime", value)

    @property
    @pulumi.getter(name="validationString")
    def validation_string(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Validation text for monitor to search for at given URI.
        """
        return pulumi.get(self, "validation_string")

    @validation_string.setter
    def validation_string(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "validation_string", value)

    @property
    @pulumi.getter(name="verifySsl")
    def verify_ssl(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Monitor should validate SSL certificate chain.
        """
        return pulumi.get(self, "verify_ssl")

    @verify_ssl.setter
    def verify_ssl(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "verify_ssl", value)


@pulumi.input_type
class _MonitorState:
    def __init__(__self__, *,
                 account_id: Optional[pulumi.Input[builtins.str]] = None,
                 browsers: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 bypass_head_request: Optional[pulumi.Input[builtins.bool]] = None,
                 custom_headers: Optional[pulumi.Input[Sequence[pulumi.Input['MonitorCustomHeaderArgs']]]] = None,
                 device_orientation: Optional[pulumi.Input[builtins.str]] = None,
                 device_type: Optional[pulumi.Input[builtins.str]] = None,
                 devices: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 enable_screenshot_on_failure_and_script: Optional[pulumi.Input[builtins.bool]] = None,
                 locations_privates: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 locations_publics: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 monitor_id: Optional[pulumi.Input[builtins.str]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 period: Optional[pulumi.Input[builtins.str]] = None,
                 period_in_minutes: Optional[pulumi.Input[builtins.int]] = None,
                 runtime_type: Optional[pulumi.Input[builtins.str]] = None,
                 runtime_type_version: Optional[pulumi.Input[builtins.str]] = None,
                 script_language: Optional[pulumi.Input[builtins.str]] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input['MonitorTagArgs']]]] = None,
                 treat_redirect_as_failure: Optional[pulumi.Input[builtins.bool]] = None,
                 type: Optional[pulumi.Input[builtins.str]] = None,
                 uri: Optional[pulumi.Input[builtins.str]] = None,
                 use_unsupported_legacy_runtime: Optional[pulumi.Input[builtins.bool]] = None,
                 validation_string: Optional[pulumi.Input[builtins.str]] = None,
                 verify_ssl: Optional[pulumi.Input[builtins.bool]] = None):
        """
        Input properties used for looking up and filtering Monitor resources.
        :param pulumi.Input[builtins.str] account_id: The account in which the Synthetics monitor will be created.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] browsers: The multiple browsers list on which synthetic monitors will run. Valid values are `CHROME` and `FIREFOX`.
        :param pulumi.Input[builtins.bool] bypass_head_request: Monitor should skip default HEAD request and instead use GET verb in check.
               
               The `BROWSER` monitor type supports the following additional arguments:
        :param pulumi.Input[Sequence[pulumi.Input['MonitorCustomHeaderArgs']]] custom_headers: Custom headers to use in monitor job. See Nested custom_header blocks below for details.
        :param pulumi.Input[builtins.str] device_orientation: Device emulation orientation field. Valid values are `LANDSCAPE` and `PORTRAIT`. 
               * We recommend you to use `devices` field instead of `device_type`,`device_orientation` fields, as it allows you to select multiple combinations of device types and orientations.
        :param pulumi.Input[builtins.str] device_type: Device emulation type field. Valid values are `MOBILE` and `TABLET`. 
               * We recommend you to use `devices` field instead of `device_type`,`device_orientation` fields, as it allows you to select multiple combinations of device types and orientations.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] devices: The multiple devices list on which synthetic monitors will run. Valid values are `DESKTOP`, `MOBILE_LANDSCAPE`, `MOBILE_PORTRAIT`, `TABLET_LANDSCAPE` and `TABLET_PORTRAIT`.
        :param pulumi.Input[builtins.bool] enable_screenshot_on_failure_and_script: Capture a screenshot during job execution.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] locations_privates: The location the monitor will run from. Accepts a list of private location GUIDs. At least one of either `locations_public` or `locations_private` is required.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] locations_publics: The location the monitor will run from. Check out [this page](https://docs.newrelic.com/docs/synthetics/synthetic-monitoring/administration/synthetic-public-minion-ips/) for a list of valid public locations. You don't need the `AWS_` prefix as the provider uses NerdGraph. At least one of either `locations_public` or `location_private` is required.
        :param pulumi.Input[builtins.str] monitor_id: The monitor id of the Synthetics monitor (not to be confused with the GUID of the monitor).
        :param pulumi.Input[builtins.str] name: The human-readable identifier for the monitor.
        :param pulumi.Input[builtins.str] period: The interval at which this monitor should run. Valid values are `EVERY_MINUTE`, `EVERY_5_MINUTES`, `EVERY_10_MINUTES`, `EVERY_15_MINUTES`, `EVERY_30_MINUTES`, `EVERY_HOUR`, `EVERY_6_HOURS`, `EVERY_12_HOURS`, or `EVERY_DAY`.
        :param pulumi.Input[builtins.int] period_in_minutes: The interval in minutes at which Synthetic monitor should run.
        :param pulumi.Input[builtins.str] runtime_type: The runtime that the monitor will use to run jobs (`CHROME_BROWSER`).
        :param pulumi.Input[builtins.str] runtime_type_version: The specific version of the runtime type selected (`100`).
        :param pulumi.Input[builtins.str] script_language: The programing language that should execute the script.
        :param pulumi.Input[builtins.str] status: The run state of the monitor. (`ENABLED` or `DISABLED`).
        :param pulumi.Input[Sequence[pulumi.Input['MonitorTagArgs']]] tags: The tags that will be associated with the monitor. See Nested tag blocks below for details.
               
               The `SIMPLE` monitor type supports the following additional arguments:
        :param pulumi.Input[builtins.bool] treat_redirect_as_failure: Categorize redirects during a monitor job as a failure.
        :param pulumi.Input[builtins.str] type: The monitor type. Valid values are `SIMPLE` and `BROWSER`.
        :param pulumi.Input[builtins.str] uri: The URI the monitor runs against.
        :param pulumi.Input[builtins.str] validation_string: Validation text for monitor to search for at given URI.
        :param pulumi.Input[builtins.bool] verify_ssl: Monitor should validate SSL certificate chain.
        """
        if account_id is not None:
            pulumi.set(__self__, "account_id", account_id)
        if browsers is not None:
            pulumi.set(__self__, "browsers", browsers)
        if bypass_head_request is not None:
            pulumi.set(__self__, "bypass_head_request", bypass_head_request)
        if custom_headers is not None:
            pulumi.set(__self__, "custom_headers", custom_headers)
        if device_orientation is not None:
            pulumi.set(__self__, "device_orientation", device_orientation)
        if device_type is not None:
            pulumi.set(__self__, "device_type", device_type)
        if devices is not None:
            pulumi.set(__self__, "devices", devices)
        if enable_screenshot_on_failure_and_script is not None:
            pulumi.set(__self__, "enable_screenshot_on_failure_and_script", enable_screenshot_on_failure_and_script)
        if locations_privates is not None:
            pulumi.set(__self__, "locations_privates", locations_privates)
        if locations_publics is not None:
            pulumi.set(__self__, "locations_publics", locations_publics)
        if monitor_id is not None:
            pulumi.set(__self__, "monitor_id", monitor_id)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if period is not None:
            pulumi.set(__self__, "period", period)
        if period_in_minutes is not None:
            pulumi.set(__self__, "period_in_minutes", period_in_minutes)
        if runtime_type is not None:
            pulumi.set(__self__, "runtime_type", runtime_type)
        if runtime_type_version is not None:
            pulumi.set(__self__, "runtime_type_version", runtime_type_version)
        if script_language is not None:
            pulumi.set(__self__, "script_language", script_language)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if treat_redirect_as_failure is not None:
            pulumi.set(__self__, "treat_redirect_as_failure", treat_redirect_as_failure)
        if type is not None:
            pulumi.set(__self__, "type", type)
        if uri is not None:
            pulumi.set(__self__, "uri", uri)
        if use_unsupported_legacy_runtime is not None:
            pulumi.set(__self__, "use_unsupported_legacy_runtime", use_unsupported_legacy_runtime)
        if validation_string is not None:
            pulumi.set(__self__, "validation_string", validation_string)
        if verify_ssl is not None:
            pulumi.set(__self__, "verify_ssl", verify_ssl)

    @property
    @pulumi.getter(name="accountId")
    def account_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The account in which the Synthetics monitor will be created.
        """
        return pulumi.get(self, "account_id")

    @account_id.setter
    def account_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "account_id", value)

    @property
    @pulumi.getter
    def browsers(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        The multiple browsers list on which synthetic monitors will run. Valid values are `CHROME` and `FIREFOX`.
        """
        return pulumi.get(self, "browsers")

    @browsers.setter
    def browsers(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "browsers", value)

    @property
    @pulumi.getter(name="bypassHeadRequest")
    def bypass_head_request(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Monitor should skip default HEAD request and instead use GET verb in check.

        The `BROWSER` monitor type supports the following additional arguments:
        """
        return pulumi.get(self, "bypass_head_request")

    @bypass_head_request.setter
    def bypass_head_request(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "bypass_head_request", value)

    @property
    @pulumi.getter(name="customHeaders")
    def custom_headers(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['MonitorCustomHeaderArgs']]]]:
        """
        Custom headers to use in monitor job. See Nested custom_header blocks below for details.
        """
        return pulumi.get(self, "custom_headers")

    @custom_headers.setter
    def custom_headers(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['MonitorCustomHeaderArgs']]]]):
        pulumi.set(self, "custom_headers", value)

    @property
    @pulumi.getter(name="deviceOrientation")
    def device_orientation(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Device emulation orientation field. Valid values are `LANDSCAPE` and `PORTRAIT`. 
        * We recommend you to use `devices` field instead of `device_type`,`device_orientation` fields, as it allows you to select multiple combinations of device types and orientations.
        """
        return pulumi.get(self, "device_orientation")

    @device_orientation.setter
    def device_orientation(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "device_orientation", value)

    @property
    @pulumi.getter(name="deviceType")
    def device_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Device emulation type field. Valid values are `MOBILE` and `TABLET`. 
        * We recommend you to use `devices` field instead of `device_type`,`device_orientation` fields, as it allows you to select multiple combinations of device types and orientations.
        """
        return pulumi.get(self, "device_type")

    @device_type.setter
    def device_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "device_type", value)

    @property
    @pulumi.getter
    def devices(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        The multiple devices list on which synthetic monitors will run. Valid values are `DESKTOP`, `MOBILE_LANDSCAPE`, `MOBILE_PORTRAIT`, `TABLET_LANDSCAPE` and `TABLET_PORTRAIT`.
        """
        return pulumi.get(self, "devices")

    @devices.setter
    def devices(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "devices", value)

    @property
    @pulumi.getter(name="enableScreenshotOnFailureAndScript")
    def enable_screenshot_on_failure_and_script(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Capture a screenshot during job execution.
        """
        return pulumi.get(self, "enable_screenshot_on_failure_and_script")

    @enable_screenshot_on_failure_and_script.setter
    def enable_screenshot_on_failure_and_script(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "enable_screenshot_on_failure_and_script", value)

    @property
    @pulumi.getter(name="locationsPrivates")
    def locations_privates(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        The location the monitor will run from. Accepts a list of private location GUIDs. At least one of either `locations_public` or `locations_private` is required.
        """
        return pulumi.get(self, "locations_privates")

    @locations_privates.setter
    def locations_privates(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "locations_privates", value)

    @property
    @pulumi.getter(name="locationsPublics")
    def locations_publics(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        The location the monitor will run from. Check out [this page](https://docs.newrelic.com/docs/synthetics/synthetic-monitoring/administration/synthetic-public-minion-ips/) for a list of valid public locations. You don't need the `AWS_` prefix as the provider uses NerdGraph. At least one of either `locations_public` or `location_private` is required.
        """
        return pulumi.get(self, "locations_publics")

    @locations_publics.setter
    def locations_publics(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "locations_publics", value)

    @property
    @pulumi.getter(name="monitorId")
    def monitor_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The monitor id of the Synthetics monitor (not to be confused with the GUID of the monitor).
        """
        return pulumi.get(self, "monitor_id")

    @monitor_id.setter
    def monitor_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "monitor_id", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The human-readable identifier for the monitor.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def period(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The interval at which this monitor should run. Valid values are `EVERY_MINUTE`, `EVERY_5_MINUTES`, `EVERY_10_MINUTES`, `EVERY_15_MINUTES`, `EVERY_30_MINUTES`, `EVERY_HOUR`, `EVERY_6_HOURS`, `EVERY_12_HOURS`, or `EVERY_DAY`.
        """
        return pulumi.get(self, "period")

    @period.setter
    def period(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "period", value)

    @property
    @pulumi.getter(name="periodInMinutes")
    def period_in_minutes(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        The interval in minutes at which Synthetic monitor should run.
        """
        return pulumi.get(self, "period_in_minutes")

    @period_in_minutes.setter
    def period_in_minutes(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "period_in_minutes", value)

    @property
    @pulumi.getter(name="runtimeType")
    def runtime_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The runtime that the monitor will use to run jobs (`CHROME_BROWSER`).
        """
        return pulumi.get(self, "runtime_type")

    @runtime_type.setter
    def runtime_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "runtime_type", value)

    @property
    @pulumi.getter(name="runtimeTypeVersion")
    def runtime_type_version(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The specific version of the runtime type selected (`100`).
        """
        return pulumi.get(self, "runtime_type_version")

    @runtime_type_version.setter
    def runtime_type_version(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "runtime_type_version", value)

    @property
    @pulumi.getter(name="scriptLanguage")
    def script_language(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The programing language that should execute the script.
        """
        return pulumi.get(self, "script_language")

    @script_language.setter
    def script_language(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "script_language", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The run state of the monitor. (`ENABLED` or `DISABLED`).
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['MonitorTagArgs']]]]:
        """
        The tags that will be associated with the monitor. See Nested tag blocks below for details.

        The `SIMPLE` monitor type supports the following additional arguments:
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['MonitorTagArgs']]]]):
        pulumi.set(self, "tags", value)

    @property
    @pulumi.getter(name="treatRedirectAsFailure")
    def treat_redirect_as_failure(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Categorize redirects during a monitor job as a failure.
        """
        return pulumi.get(self, "treat_redirect_as_failure")

    @treat_redirect_as_failure.setter
    def treat_redirect_as_failure(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "treat_redirect_as_failure", value)

    @property
    @pulumi.getter
    def type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The monitor type. Valid values are `SIMPLE` and `BROWSER`.
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "type", value)

    @property
    @pulumi.getter
    def uri(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The URI the monitor runs against.
        """
        return pulumi.get(self, "uri")

    @uri.setter
    def uri(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "uri", value)

    @property
    @pulumi.getter(name="useUnsupportedLegacyRuntime")
    def use_unsupported_legacy_runtime(self) -> Optional[pulumi.Input[builtins.bool]]:
        return pulumi.get(self, "use_unsupported_legacy_runtime")

    @use_unsupported_legacy_runtime.setter
    def use_unsupported_legacy_runtime(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "use_unsupported_legacy_runtime", value)

    @property
    @pulumi.getter(name="validationString")
    def validation_string(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Validation text for monitor to search for at given URI.
        """
        return pulumi.get(self, "validation_string")

    @validation_string.setter
    def validation_string(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "validation_string", value)

    @property
    @pulumi.getter(name="verifySsl")
    def verify_ssl(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Monitor should validate SSL certificate chain.
        """
        return pulumi.get(self, "verify_ssl")

    @verify_ssl.setter
    def verify_ssl(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "verify_ssl", value)


class Monitor(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 account_id: Optional[pulumi.Input[builtins.str]] = None,
                 browsers: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 bypass_head_request: Optional[pulumi.Input[builtins.bool]] = None,
                 custom_headers: Optional[pulumi.Input[Sequence[pulumi.Input[Union['MonitorCustomHeaderArgs', 'MonitorCustomHeaderArgsDict']]]]] = None,
                 device_orientation: Optional[pulumi.Input[builtins.str]] = None,
                 device_type: Optional[pulumi.Input[builtins.str]] = None,
                 devices: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 enable_screenshot_on_failure_and_script: Optional[pulumi.Input[builtins.bool]] = None,
                 locations_privates: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 locations_publics: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 period: Optional[pulumi.Input[builtins.str]] = None,
                 runtime_type: Optional[pulumi.Input[builtins.str]] = None,
                 runtime_type_version: Optional[pulumi.Input[builtins.str]] = None,
                 script_language: Optional[pulumi.Input[builtins.str]] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['MonitorTagArgs', 'MonitorTagArgsDict']]]]] = None,
                 treat_redirect_as_failure: Optional[pulumi.Input[builtins.bool]] = None,
                 type: Optional[pulumi.Input[builtins.str]] = None,
                 uri: Optional[pulumi.Input[builtins.str]] = None,
                 use_unsupported_legacy_runtime: Optional[pulumi.Input[builtins.bool]] = None,
                 validation_string: Optional[pulumi.Input[builtins.str]] = None,
                 verify_ssl: Optional[pulumi.Input[builtins.bool]] = None,
                 __props__=None):
        """
        ## Example Usage

        ```python
        import pulumi
        import pulumi_newrelic as newrelic

        monitor = newrelic.synthetics.Monitor("monitor",
            status="ENABLED",
            name="monitor",
            period="EVERY_MINUTE",
            uri="https://www.one.newrelic.com",
            type="SIMPLE",
            locations_publics=["AP_SOUTH_1"],
            custom_headers=[{
                "name": "some_name",
                "value": "some_value",
            }],
            treat_redirect_as_failure=True,
            validation_string="success",
            bypass_head_request=True,
            verify_ssl=True,
            tags=[{
                "key": "some_key",
                "values": ["some_value"],
            }])
        ```
        ##### Type: `SIMPLE BROWSER`

        ```python
        import pulumi
        import pulumi_newrelic as newrelic

        monitor = newrelic.synthetics.Monitor("monitor",
            status="ENABLED",
            name="monitor",
            period="EVERY_MINUTE",
            uri="https://www.one.newrelic.com",
            type="BROWSER",
            locations_publics=["AP_SOUTH_1"],
            enable_screenshot_on_failure_and_script=True,
            validation_string="success",
            verify_ssl=True,
            runtime_type="CHROME_BROWSER",
            runtime_type_version="100",
            script_language="JAVASCRIPT",
            devices=[
                "DESKTOP",
                "TABLET_LANDSCAPE",
                "MOBILE_PORTRAIT",
            ],
            browsers=["CHROME"],
            custom_headers=[{
                "name": "some_name",
                "value": "some_value",
            }],
            tags=[{
                "key": "some_key",
                "values": ["some_value"],
            }])
        ```
        See additional examples.

        ## Additional Examples

        ### Create a monitor with a private location

        The below example shows how you can define a private location and attach it to a monitor.

        > **NOTE:** It can take up to 10 minutes for a private location to become available.

        ##### Type: `SIMPLE`

        ```python
        import pulumi
        import pulumi_newrelic as newrelic

        location = newrelic.synthetics.PrivateLocation("location",
            description="Example private location",
            name="private_location",
            verified_script_execution=False)
        monitor = newrelic.synthetics.Monitor("monitor",
            status="ENABLED",
            name="monitor",
            period="EVERY_MINUTE",
            uri="https://www.one.newrelic.com",
            type="SIMPLE",
            locations_privates=[location.id],
            custom_headers=[{
                "name": "some_name",
                "value": "some_value",
            }],
            treat_redirect_as_failure=True,
            validation_string="success",
            bypass_head_request=True,
            verify_ssl=True,
            tags=[{
                "key": "some_key",
                "values": ["some_value"],
            }])
        ```
        ##### Type: `BROWSER`

        ```python
        import pulumi
        import pulumi_newrelic as newrelic

        location = newrelic.synthetics.PrivateLocation("location",
            description="Example private location",
            name="private-location",
            verified_script_execution=False)
        monitor = newrelic.synthetics.Monitor("monitor",
            status="ENABLED",
            type="BROWSER",
            uri="https://www.one.newrelic.com",
            name="monitor",
            period="EVERY_MINUTE",
            locations_privates=[location.id],
            enable_screenshot_on_failure_and_script=True,
            validation_string="success",
            verify_ssl=True,
            runtime_type_version="100",
            runtime_type="CHROME_BROWSER",
            script_language="JAVASCRIPT",
            devices=[
                "DESKTOP",
                "TABLET_LANDSCAPE",
                "MOBILE_PORTRAIT",
            ],
            browsers=["CHROME"],
            custom_headers=[{
                "name": "some_name",
                "value": "some_value",
            }],
            tags=[{
                "key": "some_key",
                "values": ["some_value"],
            }])
        ```

        ## Import

        Synthetics monitor can be imported using the `guid`, e.g.

        bash

        ```sh
        $ pulumi import newrelic:synthetics/monitor:Monitor monitor <guid>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] account_id: The account in which the Synthetics monitor will be created.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] browsers: The multiple browsers list on which synthetic monitors will run. Valid values are `CHROME` and `FIREFOX`.
        :param pulumi.Input[builtins.bool] bypass_head_request: Monitor should skip default HEAD request and instead use GET verb in check.
               
               The `BROWSER` monitor type supports the following additional arguments:
        :param pulumi.Input[Sequence[pulumi.Input[Union['MonitorCustomHeaderArgs', 'MonitorCustomHeaderArgsDict']]]] custom_headers: Custom headers to use in monitor job. See Nested custom_header blocks below for details.
        :param pulumi.Input[builtins.str] device_orientation: Device emulation orientation field. Valid values are `LANDSCAPE` and `PORTRAIT`. 
               * We recommend you to use `devices` field instead of `device_type`,`device_orientation` fields, as it allows you to select multiple combinations of device types and orientations.
        :param pulumi.Input[builtins.str] device_type: Device emulation type field. Valid values are `MOBILE` and `TABLET`. 
               * We recommend you to use `devices` field instead of `device_type`,`device_orientation` fields, as it allows you to select multiple combinations of device types and orientations.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] devices: The multiple devices list on which synthetic monitors will run. Valid values are `DESKTOP`, `MOBILE_LANDSCAPE`, `MOBILE_PORTRAIT`, `TABLET_LANDSCAPE` and `TABLET_PORTRAIT`.
        :param pulumi.Input[builtins.bool] enable_screenshot_on_failure_and_script: Capture a screenshot during job execution.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] locations_privates: The location the monitor will run from. Accepts a list of private location GUIDs. At least one of either `locations_public` or `locations_private` is required.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] locations_publics: The location the monitor will run from. Check out [this page](https://docs.newrelic.com/docs/synthetics/synthetic-monitoring/administration/synthetic-public-minion-ips/) for a list of valid public locations. You don't need the `AWS_` prefix as the provider uses NerdGraph. At least one of either `locations_public` or `location_private` is required.
        :param pulumi.Input[builtins.str] name: The human-readable identifier for the monitor.
        :param pulumi.Input[builtins.str] period: The interval at which this monitor should run. Valid values are `EVERY_MINUTE`, `EVERY_5_MINUTES`, `EVERY_10_MINUTES`, `EVERY_15_MINUTES`, `EVERY_30_MINUTES`, `EVERY_HOUR`, `EVERY_6_HOURS`, `EVERY_12_HOURS`, or `EVERY_DAY`.
        :param pulumi.Input[builtins.str] runtime_type: The runtime that the monitor will use to run jobs (`CHROME_BROWSER`).
        :param pulumi.Input[builtins.str] runtime_type_version: The specific version of the runtime type selected (`100`).
        :param pulumi.Input[builtins.str] script_language: The programing language that should execute the script.
        :param pulumi.Input[builtins.str] status: The run state of the monitor. (`ENABLED` or `DISABLED`).
        :param pulumi.Input[Sequence[pulumi.Input[Union['MonitorTagArgs', 'MonitorTagArgsDict']]]] tags: The tags that will be associated with the monitor. See Nested tag blocks below for details.
               
               The `SIMPLE` monitor type supports the following additional arguments:
        :param pulumi.Input[builtins.bool] treat_redirect_as_failure: Categorize redirects during a monitor job as a failure.
        :param pulumi.Input[builtins.str] type: The monitor type. Valid values are `SIMPLE` and `BROWSER`.
        :param pulumi.Input[builtins.str] uri: The URI the monitor runs against.
        :param pulumi.Input[builtins.str] validation_string: Validation text for monitor to search for at given URI.
        :param pulumi.Input[builtins.bool] verify_ssl: Monitor should validate SSL certificate chain.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: MonitorArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        ## Example Usage

        ```python
        import pulumi
        import pulumi_newrelic as newrelic

        monitor = newrelic.synthetics.Monitor("monitor",
            status="ENABLED",
            name="monitor",
            period="EVERY_MINUTE",
            uri="https://www.one.newrelic.com",
            type="SIMPLE",
            locations_publics=["AP_SOUTH_1"],
            custom_headers=[{
                "name": "some_name",
                "value": "some_value",
            }],
            treat_redirect_as_failure=True,
            validation_string="success",
            bypass_head_request=True,
            verify_ssl=True,
            tags=[{
                "key": "some_key",
                "values": ["some_value"],
            }])
        ```
        ##### Type: `SIMPLE BROWSER`

        ```python
        import pulumi
        import pulumi_newrelic as newrelic

        monitor = newrelic.synthetics.Monitor("monitor",
            status="ENABLED",
            name="monitor",
            period="EVERY_MINUTE",
            uri="https://www.one.newrelic.com",
            type="BROWSER",
            locations_publics=["AP_SOUTH_1"],
            enable_screenshot_on_failure_and_script=True,
            validation_string="success",
            verify_ssl=True,
            runtime_type="CHROME_BROWSER",
            runtime_type_version="100",
            script_language="JAVASCRIPT",
            devices=[
                "DESKTOP",
                "TABLET_LANDSCAPE",
                "MOBILE_PORTRAIT",
            ],
            browsers=["CHROME"],
            custom_headers=[{
                "name": "some_name",
                "value": "some_value",
            }],
            tags=[{
                "key": "some_key",
                "values": ["some_value"],
            }])
        ```
        See additional examples.

        ## Additional Examples

        ### Create a monitor with a private location

        The below example shows how you can define a private location and attach it to a monitor.

        > **NOTE:** It can take up to 10 minutes for a private location to become available.

        ##### Type: `SIMPLE`

        ```python
        import pulumi
        import pulumi_newrelic as newrelic

        location = newrelic.synthetics.PrivateLocation("location",
            description="Example private location",
            name="private_location",
            verified_script_execution=False)
        monitor = newrelic.synthetics.Monitor("monitor",
            status="ENABLED",
            name="monitor",
            period="EVERY_MINUTE",
            uri="https://www.one.newrelic.com",
            type="SIMPLE",
            locations_privates=[location.id],
            custom_headers=[{
                "name": "some_name",
                "value": "some_value",
            }],
            treat_redirect_as_failure=True,
            validation_string="success",
            bypass_head_request=True,
            verify_ssl=True,
            tags=[{
                "key": "some_key",
                "values": ["some_value"],
            }])
        ```
        ##### Type: `BROWSER`

        ```python
        import pulumi
        import pulumi_newrelic as newrelic

        location = newrelic.synthetics.PrivateLocation("location",
            description="Example private location",
            name="private-location",
            verified_script_execution=False)
        monitor = newrelic.synthetics.Monitor("monitor",
            status="ENABLED",
            type="BROWSER",
            uri="https://www.one.newrelic.com",
            name="monitor",
            period="EVERY_MINUTE",
            locations_privates=[location.id],
            enable_screenshot_on_failure_and_script=True,
            validation_string="success",
            verify_ssl=True,
            runtime_type_version="100",
            runtime_type="CHROME_BROWSER",
            script_language="JAVASCRIPT",
            devices=[
                "DESKTOP",
                "TABLET_LANDSCAPE",
                "MOBILE_PORTRAIT",
            ],
            browsers=["CHROME"],
            custom_headers=[{
                "name": "some_name",
                "value": "some_value",
            }],
            tags=[{
                "key": "some_key",
                "values": ["some_value"],
            }])
        ```

        ## Import

        Synthetics monitor can be imported using the `guid`, e.g.

        bash

        ```sh
        $ pulumi import newrelic:synthetics/monitor:Monitor monitor <guid>
        ```

        :param str resource_name: The name of the resource.
        :param MonitorArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(MonitorArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 account_id: Optional[pulumi.Input[builtins.str]] = None,
                 browsers: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 bypass_head_request: Optional[pulumi.Input[builtins.bool]] = None,
                 custom_headers: Optional[pulumi.Input[Sequence[pulumi.Input[Union['MonitorCustomHeaderArgs', 'MonitorCustomHeaderArgsDict']]]]] = None,
                 device_orientation: Optional[pulumi.Input[builtins.str]] = None,
                 device_type: Optional[pulumi.Input[builtins.str]] = None,
                 devices: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 enable_screenshot_on_failure_and_script: Optional[pulumi.Input[builtins.bool]] = None,
                 locations_privates: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 locations_publics: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 period: Optional[pulumi.Input[builtins.str]] = None,
                 runtime_type: Optional[pulumi.Input[builtins.str]] = None,
                 runtime_type_version: Optional[pulumi.Input[builtins.str]] = None,
                 script_language: Optional[pulumi.Input[builtins.str]] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['MonitorTagArgs', 'MonitorTagArgsDict']]]]] = None,
                 treat_redirect_as_failure: Optional[pulumi.Input[builtins.bool]] = None,
                 type: Optional[pulumi.Input[builtins.str]] = None,
                 uri: Optional[pulumi.Input[builtins.str]] = None,
                 use_unsupported_legacy_runtime: Optional[pulumi.Input[builtins.bool]] = None,
                 validation_string: Optional[pulumi.Input[builtins.str]] = None,
                 verify_ssl: Optional[pulumi.Input[builtins.bool]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = MonitorArgs.__new__(MonitorArgs)

            __props__.__dict__["account_id"] = account_id
            __props__.__dict__["browsers"] = browsers
            __props__.__dict__["bypass_head_request"] = bypass_head_request
            __props__.__dict__["custom_headers"] = custom_headers
            __props__.__dict__["device_orientation"] = device_orientation
            __props__.__dict__["device_type"] = device_type
            __props__.__dict__["devices"] = devices
            __props__.__dict__["enable_screenshot_on_failure_and_script"] = enable_screenshot_on_failure_and_script
            __props__.__dict__["locations_privates"] = locations_privates
            __props__.__dict__["locations_publics"] = locations_publics
            __props__.__dict__["name"] = name
            __props__.__dict__["period"] = period
            __props__.__dict__["runtime_type"] = runtime_type
            __props__.__dict__["runtime_type_version"] = runtime_type_version
            __props__.__dict__["script_language"] = script_language
            if status is None and not opts.urn:
                raise TypeError("Missing required property 'status'")
            __props__.__dict__["status"] = status
            __props__.__dict__["tags"] = tags
            __props__.__dict__["treat_redirect_as_failure"] = treat_redirect_as_failure
            if type is None and not opts.urn:
                raise TypeError("Missing required property 'type'")
            __props__.__dict__["type"] = type
            __props__.__dict__["uri"] = uri
            __props__.__dict__["use_unsupported_legacy_runtime"] = use_unsupported_legacy_runtime
            __props__.__dict__["validation_string"] = validation_string
            __props__.__dict__["verify_ssl"] = verify_ssl
            __props__.__dict__["monitor_id"] = None
            __props__.__dict__["period_in_minutes"] = None
        super(Monitor, __self__).__init__(
            'newrelic:synthetics/monitor:Monitor',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            account_id: Optional[pulumi.Input[builtins.str]] = None,
            browsers: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
            bypass_head_request: Optional[pulumi.Input[builtins.bool]] = None,
            custom_headers: Optional[pulumi.Input[Sequence[pulumi.Input[Union['MonitorCustomHeaderArgs', 'MonitorCustomHeaderArgsDict']]]]] = None,
            device_orientation: Optional[pulumi.Input[builtins.str]] = None,
            device_type: Optional[pulumi.Input[builtins.str]] = None,
            devices: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
            enable_screenshot_on_failure_and_script: Optional[pulumi.Input[builtins.bool]] = None,
            locations_privates: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
            locations_publics: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
            monitor_id: Optional[pulumi.Input[builtins.str]] = None,
            name: Optional[pulumi.Input[builtins.str]] = None,
            period: Optional[pulumi.Input[builtins.str]] = None,
            period_in_minutes: Optional[pulumi.Input[builtins.int]] = None,
            runtime_type: Optional[pulumi.Input[builtins.str]] = None,
            runtime_type_version: Optional[pulumi.Input[builtins.str]] = None,
            script_language: Optional[pulumi.Input[builtins.str]] = None,
            status: Optional[pulumi.Input[builtins.str]] = None,
            tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['MonitorTagArgs', 'MonitorTagArgsDict']]]]] = None,
            treat_redirect_as_failure: Optional[pulumi.Input[builtins.bool]] = None,
            type: Optional[pulumi.Input[builtins.str]] = None,
            uri: Optional[pulumi.Input[builtins.str]] = None,
            use_unsupported_legacy_runtime: Optional[pulumi.Input[builtins.bool]] = None,
            validation_string: Optional[pulumi.Input[builtins.str]] = None,
            verify_ssl: Optional[pulumi.Input[builtins.bool]] = None) -> 'Monitor':
        """
        Get an existing Monitor resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] account_id: The account in which the Synthetics monitor will be created.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] browsers: The multiple browsers list on which synthetic monitors will run. Valid values are `CHROME` and `FIREFOX`.
        :param pulumi.Input[builtins.bool] bypass_head_request: Monitor should skip default HEAD request and instead use GET verb in check.
               
               The `BROWSER` monitor type supports the following additional arguments:
        :param pulumi.Input[Sequence[pulumi.Input[Union['MonitorCustomHeaderArgs', 'MonitorCustomHeaderArgsDict']]]] custom_headers: Custom headers to use in monitor job. See Nested custom_header blocks below for details.
        :param pulumi.Input[builtins.str] device_orientation: Device emulation orientation field. Valid values are `LANDSCAPE` and `PORTRAIT`. 
               * We recommend you to use `devices` field instead of `device_type`,`device_orientation` fields, as it allows you to select multiple combinations of device types and orientations.
        :param pulumi.Input[builtins.str] device_type: Device emulation type field. Valid values are `MOBILE` and `TABLET`. 
               * We recommend you to use `devices` field instead of `device_type`,`device_orientation` fields, as it allows you to select multiple combinations of device types and orientations.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] devices: The multiple devices list on which synthetic monitors will run. Valid values are `DESKTOP`, `MOBILE_LANDSCAPE`, `MOBILE_PORTRAIT`, `TABLET_LANDSCAPE` and `TABLET_PORTRAIT`.
        :param pulumi.Input[builtins.bool] enable_screenshot_on_failure_and_script: Capture a screenshot during job execution.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] locations_privates: The location the monitor will run from. Accepts a list of private location GUIDs. At least one of either `locations_public` or `locations_private` is required.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] locations_publics: The location the monitor will run from. Check out [this page](https://docs.newrelic.com/docs/synthetics/synthetic-monitoring/administration/synthetic-public-minion-ips/) for a list of valid public locations. You don't need the `AWS_` prefix as the provider uses NerdGraph. At least one of either `locations_public` or `location_private` is required.
        :param pulumi.Input[builtins.str] monitor_id: The monitor id of the Synthetics monitor (not to be confused with the GUID of the monitor).
        :param pulumi.Input[builtins.str] name: The human-readable identifier for the monitor.
        :param pulumi.Input[builtins.str] period: The interval at which this monitor should run. Valid values are `EVERY_MINUTE`, `EVERY_5_MINUTES`, `EVERY_10_MINUTES`, `EVERY_15_MINUTES`, `EVERY_30_MINUTES`, `EVERY_HOUR`, `EVERY_6_HOURS`, `EVERY_12_HOURS`, or `EVERY_DAY`.
        :param pulumi.Input[builtins.int] period_in_minutes: The interval in minutes at which Synthetic monitor should run.
        :param pulumi.Input[builtins.str] runtime_type: The runtime that the monitor will use to run jobs (`CHROME_BROWSER`).
        :param pulumi.Input[builtins.str] runtime_type_version: The specific version of the runtime type selected (`100`).
        :param pulumi.Input[builtins.str] script_language: The programing language that should execute the script.
        :param pulumi.Input[builtins.str] status: The run state of the monitor. (`ENABLED` or `DISABLED`).
        :param pulumi.Input[Sequence[pulumi.Input[Union['MonitorTagArgs', 'MonitorTagArgsDict']]]] tags: The tags that will be associated with the monitor. See Nested tag blocks below for details.
               
               The `SIMPLE` monitor type supports the following additional arguments:
        :param pulumi.Input[builtins.bool] treat_redirect_as_failure: Categorize redirects during a monitor job as a failure.
        :param pulumi.Input[builtins.str] type: The monitor type. Valid values are `SIMPLE` and `BROWSER`.
        :param pulumi.Input[builtins.str] uri: The URI the monitor runs against.
        :param pulumi.Input[builtins.str] validation_string: Validation text for monitor to search for at given URI.
        :param pulumi.Input[builtins.bool] verify_ssl: Monitor should validate SSL certificate chain.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _MonitorState.__new__(_MonitorState)

        __props__.__dict__["account_id"] = account_id
        __props__.__dict__["browsers"] = browsers
        __props__.__dict__["bypass_head_request"] = bypass_head_request
        __props__.__dict__["custom_headers"] = custom_headers
        __props__.__dict__["device_orientation"] = device_orientation
        __props__.__dict__["device_type"] = device_type
        __props__.__dict__["devices"] = devices
        __props__.__dict__["enable_screenshot_on_failure_and_script"] = enable_screenshot_on_failure_and_script
        __props__.__dict__["locations_privates"] = locations_privates
        __props__.__dict__["locations_publics"] = locations_publics
        __props__.__dict__["monitor_id"] = monitor_id
        __props__.__dict__["name"] = name
        __props__.__dict__["period"] = period
        __props__.__dict__["period_in_minutes"] = period_in_minutes
        __props__.__dict__["runtime_type"] = runtime_type
        __props__.__dict__["runtime_type_version"] = runtime_type_version
        __props__.__dict__["script_language"] = script_language
        __props__.__dict__["status"] = status
        __props__.__dict__["tags"] = tags
        __props__.__dict__["treat_redirect_as_failure"] = treat_redirect_as_failure
        __props__.__dict__["type"] = type
        __props__.__dict__["uri"] = uri
        __props__.__dict__["use_unsupported_legacy_runtime"] = use_unsupported_legacy_runtime
        __props__.__dict__["validation_string"] = validation_string
        __props__.__dict__["verify_ssl"] = verify_ssl
        return Monitor(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="accountId")
    def account_id(self) -> pulumi.Output[builtins.str]:
        """
        The account in which the Synthetics monitor will be created.
        """
        return pulumi.get(self, "account_id")

    @property
    @pulumi.getter
    def browsers(self) -> pulumi.Output[Optional[Sequence[builtins.str]]]:
        """
        The multiple browsers list on which synthetic monitors will run. Valid values are `CHROME` and `FIREFOX`.
        """
        return pulumi.get(self, "browsers")

    @property
    @pulumi.getter(name="bypassHeadRequest")
    def bypass_head_request(self) -> pulumi.Output[Optional[builtins.bool]]:
        """
        Monitor should skip default HEAD request and instead use GET verb in check.

        The `BROWSER` monitor type supports the following additional arguments:
        """
        return pulumi.get(self, "bypass_head_request")

    @property
    @pulumi.getter(name="customHeaders")
    def custom_headers(self) -> pulumi.Output[Optional[Sequence['outputs.MonitorCustomHeader']]]:
        """
        Custom headers to use in monitor job. See Nested custom_header blocks below for details.
        """
        return pulumi.get(self, "custom_headers")

    @property
    @pulumi.getter(name="deviceOrientation")
    def device_orientation(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Device emulation orientation field. Valid values are `LANDSCAPE` and `PORTRAIT`. 
        * We recommend you to use `devices` field instead of `device_type`,`device_orientation` fields, as it allows you to select multiple combinations of device types and orientations.
        """
        return pulumi.get(self, "device_orientation")

    @property
    @pulumi.getter(name="deviceType")
    def device_type(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Device emulation type field. Valid values are `MOBILE` and `TABLET`. 
        * We recommend you to use `devices` field instead of `device_type`,`device_orientation` fields, as it allows you to select multiple combinations of device types and orientations.
        """
        return pulumi.get(self, "device_type")

    @property
    @pulumi.getter
    def devices(self) -> pulumi.Output[Optional[Sequence[builtins.str]]]:
        """
        The multiple devices list on which synthetic monitors will run. Valid values are `DESKTOP`, `MOBILE_LANDSCAPE`, `MOBILE_PORTRAIT`, `TABLET_LANDSCAPE` and `TABLET_PORTRAIT`.
        """
        return pulumi.get(self, "devices")

    @property
    @pulumi.getter(name="enableScreenshotOnFailureAndScript")
    def enable_screenshot_on_failure_and_script(self) -> pulumi.Output[Optional[builtins.bool]]:
        """
        Capture a screenshot during job execution.
        """
        return pulumi.get(self, "enable_screenshot_on_failure_and_script")

    @property
    @pulumi.getter(name="locationsPrivates")
    def locations_privates(self) -> pulumi.Output[Optional[Sequence[builtins.str]]]:
        """
        The location the monitor will run from. Accepts a list of private location GUIDs. At least one of either `locations_public` or `locations_private` is required.
        """
        return pulumi.get(self, "locations_privates")

    @property
    @pulumi.getter(name="locationsPublics")
    def locations_publics(self) -> pulumi.Output[Optional[Sequence[builtins.str]]]:
        """
        The location the monitor will run from. Check out [this page](https://docs.newrelic.com/docs/synthetics/synthetic-monitoring/administration/synthetic-public-minion-ips/) for a list of valid public locations. You don't need the `AWS_` prefix as the provider uses NerdGraph. At least one of either `locations_public` or `location_private` is required.
        """
        return pulumi.get(self, "locations_publics")

    @property
    @pulumi.getter(name="monitorId")
    def monitor_id(self) -> pulumi.Output[builtins.str]:
        """
        The monitor id of the Synthetics monitor (not to be confused with the GUID of the monitor).
        """
        return pulumi.get(self, "monitor_id")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[builtins.str]:
        """
        The human-readable identifier for the monitor.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def period(self) -> pulumi.Output[builtins.str]:
        """
        The interval at which this monitor should run. Valid values are `EVERY_MINUTE`, `EVERY_5_MINUTES`, `EVERY_10_MINUTES`, `EVERY_15_MINUTES`, `EVERY_30_MINUTES`, `EVERY_HOUR`, `EVERY_6_HOURS`, `EVERY_12_HOURS`, or `EVERY_DAY`.
        """
        return pulumi.get(self, "period")

    @property
    @pulumi.getter(name="periodInMinutes")
    def period_in_minutes(self) -> pulumi.Output[builtins.int]:
        """
        The interval in minutes at which Synthetic monitor should run.
        """
        return pulumi.get(self, "period_in_minutes")

    @property
    @pulumi.getter(name="runtimeType")
    def runtime_type(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        The runtime that the monitor will use to run jobs (`CHROME_BROWSER`).
        """
        return pulumi.get(self, "runtime_type")

    @property
    @pulumi.getter(name="runtimeTypeVersion")
    def runtime_type_version(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        The specific version of the runtime type selected (`100`).
        """
        return pulumi.get(self, "runtime_type_version")

    @property
    @pulumi.getter(name="scriptLanguage")
    def script_language(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        The programing language that should execute the script.
        """
        return pulumi.get(self, "script_language")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[builtins.str]:
        """
        The run state of the monitor. (`ENABLED` or `DISABLED`).
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Optional[Sequence['outputs.MonitorTag']]]:
        """
        The tags that will be associated with the monitor. See Nested tag blocks below for details.

        The `SIMPLE` monitor type supports the following additional arguments:
        """
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter(name="treatRedirectAsFailure")
    def treat_redirect_as_failure(self) -> pulumi.Output[Optional[builtins.bool]]:
        """
        Categorize redirects during a monitor job as a failure.
        """
        return pulumi.get(self, "treat_redirect_as_failure")

    @property
    @pulumi.getter
    def type(self) -> pulumi.Output[builtins.str]:
        """
        The monitor type. Valid values are `SIMPLE` and `BROWSER`.
        """
        return pulumi.get(self, "type")

    @property
    @pulumi.getter
    def uri(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        The URI the monitor runs against.
        """
        return pulumi.get(self, "uri")

    @property
    @pulumi.getter(name="useUnsupportedLegacyRuntime")
    def use_unsupported_legacy_runtime(self) -> pulumi.Output[Optional[builtins.bool]]:
        return pulumi.get(self, "use_unsupported_legacy_runtime")

    @property
    @pulumi.getter(name="validationString")
    def validation_string(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Validation text for monitor to search for at given URI.
        """
        return pulumi.get(self, "validation_string")

    @property
    @pulumi.getter(name="verifySsl")
    def verify_ssl(self) -> pulumi.Output[Optional[builtins.bool]]:
        """
        Monitor should validate SSL certificate chain.
        """
        return pulumi.get(self, "verify_ssl")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['ObfuscationExpressionArgs', 'ObfuscationExpression']

@pulumi.input_type
class ObfuscationExpressionArgs:
    def __init__(__self__, *,
                 regex: pulumi.Input[builtins.str],
                 account_id: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None):
        """
        The set of arguments for constructing a ObfuscationExpression resource.
        :param pulumi.Input[builtins.str] regex: Regex of expression. Must be wrapped in parentheses, e.g. (regex.*).
        :param pulumi.Input[builtins.str] account_id: The account id associated with the obfuscation expression.
        :param pulumi.Input[builtins.str] description: Description of expression.
        :param pulumi.Input[builtins.str] name: Name of expression.
        """
        pulumi.set(__self__, "regex", regex)
        if account_id is not None:
            pulumi.set(__self__, "account_id", account_id)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if name is not None:
            pulumi.set(__self__, "name", name)

    @property
    @pulumi.getter
    def regex(self) -> pulumi.Input[builtins.str]:
        """
        Regex of expression. Must be wrapped in parentheses, e.g. (regex.*).
        """
        return pulumi.get(self, "regex")

    @regex.setter
    def regex(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "regex", value)

    @property
    @pulumi.getter(name="accountId")
    def account_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The account id associated with the obfuscation expression.
        """
        return pulumi.get(self, "account_id")

    @account_id.setter
    def account_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "account_id", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Description of expression.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Name of expression.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "name", value)


@pulumi.input_type
class _ObfuscationExpressionState:
    def __init__(__self__, *,
                 account_id: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 regex: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering ObfuscationExpression resources.
        :param pulumi.Input[builtins.str] account_id: The account id associated with the obfuscation expression.
        :param pulumi.Input[builtins.str] description: Description of expression.
        :param pulumi.Input[builtins.str] name: Name of expression.
        :param pulumi.Input[builtins.str] regex: Regex of expression. Must be wrapped in parentheses, e.g. (regex.*).
        """
        if account_id is not None:
            pulumi.set(__self__, "account_id", account_id)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if regex is not None:
            pulumi.set(__self__, "regex", regex)

    @property
    @pulumi.getter(name="accountId")
    def account_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The account id associated with the obfuscation expression.
        """
        return pulumi.get(self, "account_id")

    @account_id.setter
    def account_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "account_id", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Description of expression.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Name of expression.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def regex(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Regex of expression. Must be wrapped in parentheses, e.g. (regex.*).
        """
        return pulumi.get(self, "regex")

    @regex.setter
    def regex(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "regex", value)


class ObfuscationExpression(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 account_id: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 regex: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        Use this resource to create, update and delete New Relic Obfuscation Expressions.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_newrelic as newrelic

        foo = newrelic.ObfuscationExpression("foo",
            account_id="12345",
            name="OExp",
            description="The description",
            regex="(regex.*)")
        ```

        ## Import

        New Relic obfuscation expression can be imported using the expression ID, e.g.

        bash

        ```sh
        $ pulumi import newrelic:index/obfuscationExpression:ObfuscationExpression foo 34567
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] account_id: The account id associated with the obfuscation expression.
        :param pulumi.Input[builtins.str] description: Description of expression.
        :param pulumi.Input[builtins.str] name: Name of expression.
        :param pulumi.Input[builtins.str] regex: Regex of expression. Must be wrapped in parentheses, e.g. (regex.*).
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ObfuscationExpressionArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Use this resource to create, update and delete New Relic Obfuscation Expressions.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_newrelic as newrelic

        foo = newrelic.ObfuscationExpression("foo",
            account_id="12345",
            name="OExp",
            description="The description",
            regex="(regex.*)")
        ```

        ## Import

        New Relic obfuscation expression can be imported using the expression ID, e.g.

        bash

        ```sh
        $ pulumi import newrelic:index/obfuscationExpression:ObfuscationExpression foo 34567
        ```

        :param str resource_name: The name of the resource.
        :param ObfuscationExpressionArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ObfuscationExpressionArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 account_id: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 regex: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ObfuscationExpressionArgs.__new__(ObfuscationExpressionArgs)

            __props__.__dict__["account_id"] = account_id
            __props__.__dict__["description"] = description
            __props__.__dict__["name"] = name
            if regex is None and not opts.urn:
                raise TypeError("Missing required property 'regex'")
            __props__.__dict__["regex"] = regex
        super(ObfuscationExpression, __self__).__init__(
            'newrelic:index/obfuscationExpression:ObfuscationExpression',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            account_id: Optional[pulumi.Input[builtins.str]] = None,
            description: Optional[pulumi.Input[builtins.str]] = None,
            name: Optional[pulumi.Input[builtins.str]] = None,
            regex: Optional[pulumi.Input[builtins.str]] = None) -> 'ObfuscationExpression':
        """
        Get an existing ObfuscationExpression resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] account_id: The account id associated with the obfuscation expression.
        :param pulumi.Input[builtins.str] description: Description of expression.
        :param pulumi.Input[builtins.str] name: Name of expression.
        :param pulumi.Input[builtins.str] regex: Regex of expression. Must be wrapped in parentheses, e.g. (regex.*).
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ObfuscationExpressionState.__new__(_ObfuscationExpressionState)

        __props__.__dict__["account_id"] = account_id
        __props__.__dict__["description"] = description
        __props__.__dict__["name"] = name
        __props__.__dict__["regex"] = regex
        return ObfuscationExpression(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="accountId")
    def account_id(self) -> pulumi.Output[builtins.str]:
        """
        The account id associated with the obfuscation expression.
        """
        return pulumi.get(self, "account_id")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Description of expression.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[builtins.str]:
        """
        Name of expression.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def regex(self) -> pulumi.Output[builtins.str]:
        """
        Regex of expression. Must be wrapped in parentheses, e.g. (regex.*).
        """
        return pulumi.get(self, "regex")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

import types

__config__ = pulumi.Config('newrelic')


class _ExportableConfig(types.ModuleType):
    @property
    def account_id(self) -> Optional[str]:
        return __config__.get('accountId') or _utilities.get_env('NEW_RELIC_ACCOUNT_ID')

    @property
    def admin_api_key(self) -> Optional[str]:
        return __config__.get('adminApiKey')

    @property
    def api_key(self) -> Optional[str]:
        return __config__.get('apiKey')

    @property
    def api_url(self) -> Optional[str]:
        return __config__.get('apiUrl')

    @property
    def cacert_file(self) -> Optional[str]:
        return __config__.get('cacertFile')

    @property
    def infrastructure_api_url(self) -> Optional[str]:
        return __config__.get('infrastructureApiUrl')

    @property
    def insecure_skip_verify(self) -> Optional[bool]:
        return __config__.get_bool('insecureSkipVerify')

    @property
    def insights_insert_key(self) -> Optional[str]:
        return __config__.get('insightsInsertKey')

    @property
    def insights_insert_url(self) -> Optional[str]:
        return __config__.get('insightsInsertUrl')

    @property
    def insights_query_url(self) -> Optional[str]:
        return __config__.get('insightsQueryUrl')

    @property
    def nerdgraph_api_url(self) -> Optional[str]:
        return __config__.get('nerdgraphApiUrl')

    @property
    def region(self) -> str:
        """
        The data center for which your New Relic account is configured. Only one region per provider block is permitted.
        """
        return __config__.get('region') or (_utilities.get_env('NEW_RELIC_REGION') or 'US')

    @property
    def synthetics_api_url(self) -> Optional[str]:
        return __config__.get('syntheticsApiUrl')




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = [
    'GetServiceLevelAlertHelperResult',
    'AwaitableGetServiceLevelAlertHelperResult',
    'get_service_level_alert_helper',
    'get_service_level_alert_helper_output',
]

@pulumi.output_type
class GetServiceLevelAlertHelperResult:
    """
    A collection of values returned by getServiceLevelAlertHelper.
    """
    def __init__(__self__, alert_type=None, custom_evaluation_period=None, custom_tolerated_budget_consumption=None, evaluation_period=None, id=None, is_bad_events=None, nrql=None, sli_guid=None, slo_period=None, slo_target=None, threshold=None, tolerated_budget_consumption=None):
        if alert_type and not isinstance(alert_type, str):
            raise TypeError("Expected argument 'alert_type' to be a str")
        pulumi.set(__self__, "alert_type", alert_type)
        if custom_evaluation_period and not isinstance(custom_evaluation_period, int):
            raise TypeError("Expected argument 'custom_evaluation_period' to be a int")
        pulumi.set(__self__, "custom_evaluation_period", custom_evaluation_period)
        if custom_tolerated_budget_consumption and not isinstance(custom_tolerated_budget_consumption, float):
            raise TypeError("Expected argument 'custom_tolerated_budget_consumption' to be a float")
        pulumi.set(__self__, "custom_tolerated_budget_consumption", custom_tolerated_budget_consumption)
        if evaluation_period and not isinstance(evaluation_period, int):
            raise TypeError("Expected argument 'evaluation_period' to be a int")
        pulumi.set(__self__, "evaluation_period", evaluation_period)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if is_bad_events and not isinstance(is_bad_events, bool):
            raise TypeError("Expected argument 'is_bad_events' to be a bool")
        pulumi.set(__self__, "is_bad_events", is_bad_events)
        if nrql and not isinstance(nrql, str):
            raise TypeError("Expected argument 'nrql' to be a str")
        pulumi.set(__self__, "nrql", nrql)
        if sli_guid and not isinstance(sli_guid, str):
            raise TypeError("Expected argument 'sli_guid' to be a str")
        pulumi.set(__self__, "sli_guid", sli_guid)
        if slo_period and not isinstance(slo_period, int):
            raise TypeError("Expected argument 'slo_period' to be a int")
        pulumi.set(__self__, "slo_period", slo_period)
        if slo_target and not isinstance(slo_target, float):
            raise TypeError("Expected argument 'slo_target' to be a float")
        pulumi.set(__self__, "slo_target", slo_target)
        if threshold and not isinstance(threshold, float):
            raise TypeError("Expected argument 'threshold' to be a float")
        pulumi.set(__self__, "threshold", threshold)
        if tolerated_budget_consumption and not isinstance(tolerated_budget_consumption, float):
            raise TypeError("Expected argument 'tolerated_budget_consumption' to be a float")
        pulumi.set(__self__, "tolerated_budget_consumption", tolerated_budget_consumption)

    @property
    @pulumi.getter(name="alertType")
    def alert_type(self) -> builtins.str:
        return pulumi.get(self, "alert_type")

    @property
    @pulumi.getter(name="customEvaluationPeriod")
    def custom_evaluation_period(self) -> Optional[builtins.int]:
        return pulumi.get(self, "custom_evaluation_period")

    @property
    @pulumi.getter(name="customToleratedBudgetConsumption")
    def custom_tolerated_budget_consumption(self) -> Optional[builtins.float]:
        return pulumi.get(self, "custom_tolerated_budget_consumption")

    @property
    @pulumi.getter(name="evaluationPeriod")
    def evaluation_period(self) -> builtins.int:
        """
        (Computed) For non `custom` alert_type, this is the recommended for that type of alert. For `custom` alert_type it has the same value as `custom_evaluation_period`.
        """
        return pulumi.get(self, "evaluation_period")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="isBadEvents")
    def is_bad_events(self) -> Optional[builtins.bool]:
        return pulumi.get(self, "is_bad_events")

    @property
    @pulumi.getter
    def nrql(self) -> builtins.str:
        """
        (Computed) The nrql query for the selected type of alert.
        """
        return pulumi.get(self, "nrql")

    @property
    @pulumi.getter(name="sliGuid")
    def sli_guid(self) -> builtins.str:
        return pulumi.get(self, "sli_guid")

    @property
    @pulumi.getter(name="sloPeriod")
    def slo_period(self) -> builtins.int:
        return pulumi.get(self, "slo_period")

    @property
    @pulumi.getter(name="sloTarget")
    def slo_target(self) -> builtins.float:
        return pulumi.get(self, "slo_target")

    @property
    @pulumi.getter
    def threshold(self) -> builtins.float:
        """
        (Computed) The computed threshold given the provided arguments.
        """
        return pulumi.get(self, "threshold")

    @property
    @pulumi.getter(name="toleratedBudgetConsumption")
    def tolerated_budget_consumption(self) -> builtins.float:
        """
        (Computed) For non `custom` alert_type, this is the recommended for that type of alert. For `custom` alert_type it has the same value as `custom_tolerated_budget_consumption`.
        """
        return pulumi.get(self, "tolerated_budget_consumption")


class AwaitableGetServiceLevelAlertHelperResult(GetServiceLevelAlertHelperResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetServiceLevelAlertHelperResult(
            alert_type=self.alert_type,
            custom_evaluation_period=self.custom_evaluation_period,
            custom_tolerated_budget_consumption=self.custom_tolerated_budget_consumption,
            evaluation_period=self.evaluation_period,
            id=self.id,
            is_bad_events=self.is_bad_events,
            nrql=self.nrql,
            sli_guid=self.sli_guid,
            slo_period=self.slo_period,
            slo_target=self.slo_target,
            threshold=self.threshold,
            tolerated_budget_consumption=self.tolerated_budget_consumption)


def get_service_level_alert_helper(alert_type: Optional[builtins.str] = None,
                                   custom_evaluation_period: Optional[builtins.int] = None,
                                   custom_tolerated_budget_consumption: Optional[builtins.float] = None,
                                   is_bad_events: Optional[builtins.bool] = None,
                                   sli_guid: Optional[builtins.str] = None,
                                   slo_period: Optional[builtins.int] = None,
                                   slo_target: Optional[builtins.float] = None,
                                   opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetServiceLevelAlertHelperResult:
    """
    Use this data source to obtain the necessary fields to set up alerts on your service levels. It can be used for a `custom` alert_type in order to set up an alert with custom tolerated budget consumption and custom evaluation period or for recommended ones like `fast_burn` or `slow_burn`. For more information check [the documentation](https://docs.newrelic.com/docs/service-level-management/alerts-slm/).

    ## Example Usage

    Firstly set up your service level objective, we recommend using local variables for the `target` and `time_window.rolling.count`, as they are also necessary for the helper.

    ```python
    import pulumi
    import pulumi_newrelic as newrelic

    foo_target = 99.9
    foo_period = 28
    foo = newrelic.ServiceLevel("foo",
        guid="MXxBUE18QVBQTElDQVRJT058MQ",
        name="Latency",
        description="Proportion of requests that are served faster than a threshold.",
        events={
            "account_id": "12345678",
            "valid_events": {
                "from_": "Transaction",
                "where": "appName = 'Example application' AND (transactionType='Web')",
            },
            "bad_events": {
                "from_": "Transaction",
                "where": "appName = 'Example application' AND (transactionType= 'Web') AND duration > 0.1",
            },
        },
        objective={
            "target": foo_target,
            "time_window": {
                "rolling": {
                    "count": foo_period,
                    "unit": "DAY",
                },
            },
        })
    ```
    Then use the helper to obtain the necessary fields to set up an alert on that Service Level.
    Note that the Service Level was set up using bad events, that's why `is_bad_events` is set to `true`.
    If the Service Level was configured with good events that would be unnecessary as the field defaults to `false`.

    Here is an example of a `slow_burn` alert.

    ```python
    import pulumi
    import pulumi_newrelic as newrelic

    foo_slow_burn = newrelic.get_service_level_alert_helper(alert_type="slow_burn",
        sli_guid=foo["sliGuid"],
        slo_target=foo_target,
        slo_period=foo_period,
        is_bad_events=True)
    your_condition = newrelic.NrqlAlertCondition("your_condition",
        account_id="12345678",
        policy_id="67890",
        type="static",
        name="Slow burn alert",
        enabled=True,
        violation_time_limit_seconds=259200,
        nrql={
            "query": foo_slow_burn.nrql,
        },
        critical={
            "operator": "above_or_equals",
            "threshold": foo_slow_burn.threshold,
            "threshold_duration": 900,
            "threshold_occurrences": "at_least_once",
        },
        fill_option="none",
        aggregation_window=foo_slow_burn.evaluation_period,
        aggregation_method="event_flow",
        aggregation_delay="120",
        slide_by=900)
    ```

    Here is an example of a custom alert:

    ```python
    import pulumi
    import pulumi_newrelic as newrelic

    foo_custom = newrelic.get_service_level_alert_helper(alert_type="custom",
        sli_guid=foo["sliGuid"],
        slo_target=foo_target,
        slo_period=foo_period,
        custom_tolerated_budget_consumption=4,
        custom_evaluation_period=5400,
        is_bad_events=True)
    your_condition = newrelic.NrqlAlertCondition("your_condition",
        account_id="12345678",
        policy_id="67890",
        type="static",
        name="Custom burn alert",
        enabled=True,
        violation_time_limit_seconds=259200,
        nrql={
            "query": foo_custom.nrql,
        },
        critical={
            "operator": "above_or_equals",
            "threshold": foo_custom.threshold,
            "threshold_duration": 900,
            "threshold_occurrences": "at_least_once",
        },
        fill_option="none",
        aggregation_window=foo_custom.evaluation_period,
        aggregation_method="event_flow",
        aggregation_delay="120",
        slide_by=60)
    ```


    :param builtins.str alert_type: The type of alert we want to set. Valid values are:
    :param builtins.int custom_evaluation_period: Aggregation window taken into consideration in seconds. Mandatory if `alert_type` is `custom`.
    :param builtins.float custom_tolerated_budget_consumption: How much budget you tolerate to consume during the custom evaluation period, valid values between `0` and `100`. Mandatory if `alert_type` is `custom`.
    :param builtins.bool is_bad_events: If the SLI is defined using bad events. Defaults to `false`
    :param builtins.str sli_guid: The guid of the sli we want to set the alert on.
    :param builtins.int slo_period: The time window of the Service Level Objective in days. Valid values are `1`, `7` and `28`.
    :param builtins.float slo_target: The target of the Service Level Objective, valid values between `0` and `100`.
    """
    __args__ = dict()
    __args__['alertType'] = alert_type
    __args__['customEvaluationPeriod'] = custom_evaluation_period
    __args__['customToleratedBudgetConsumption'] = custom_tolerated_budget_consumption
    __args__['isBadEvents'] = is_bad_events
    __args__['sliGuid'] = sli_guid
    __args__['sloPeriod'] = slo_period
    __args__['sloTarget'] = slo_target
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('newrelic:index/getServiceLevelAlertHelper:getServiceLevelAlertHelper', __args__, opts=opts, typ=GetServiceLevelAlertHelperResult).value

    return AwaitableGetServiceLevelAlertHelperResult(
        alert_type=pulumi.get(__ret__, 'alert_type'),
        custom_evaluation_period=pulumi.get(__ret__, 'custom_evaluation_period'),
        custom_tolerated_budget_consumption=pulumi.get(__ret__, 'custom_tolerated_budget_consumption'),
        evaluation_period=pulumi.get(__ret__, 'evaluation_period'),
        id=pulumi.get(__ret__, 'id'),
        is_bad_events=pulumi.get(__ret__, 'is_bad_events'),
        nrql=pulumi.get(__ret__, 'nrql'),
        sli_guid=pulumi.get(__ret__, 'sli_guid'),
        slo_period=pulumi.get(__ret__, 'slo_period'),
        slo_target=pulumi.get(__ret__, 'slo_target'),
        threshold=pulumi.get(__ret__, 'threshold'),
        tolerated_budget_consumption=pulumi.get(__ret__, 'tolerated_budget_consumption'))
def get_service_level_alert_helper_output(alert_type: Optional[pulumi.Input[builtins.str]] = None,
                                          custom_evaluation_period: Optional[pulumi.Input[Optional[builtins.int]]] = None,
                                          custom_tolerated_budget_consumption: Optional[pulumi.Input[Optional[builtins.float]]] = None,
                                          is_bad_events: Optional[pulumi.Input[Optional[builtins.bool]]] = None,
                                          sli_guid: Optional[pulumi.Input[builtins.str]] = None,
                                          slo_period: Optional[pulumi.Input[builtins.int]] = None,
                                          slo_target: Optional[pulumi.Input[builtins.float]] = None,
                                          opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetServiceLevelAlertHelperResult]:
    """
    Use this data source to obtain the necessary fields to set up alerts on your service levels. It can be used for a `custom` alert_type in order to set up an alert with custom tolerated budget consumption and custom evaluation period or for recommended ones like `fast_burn` or `slow_burn`. For more information check [the documentation](https://docs.newrelic.com/docs/service-level-management/alerts-slm/).

    ## Example Usage

    Firstly set up your service level objective, we recommend using local variables for the `target` and `time_window.rolling.count`, as they are also necessary for the helper.

    ```python
    import pulumi
    import pulumi_newrelic as newrelic

    foo_target = 99.9
    foo_period = 28
    foo = newrelic.ServiceLevel("foo",
        guid="MXxBUE18QVBQTElDQVRJT058MQ",
        name="Latency",
        description="Proportion of requests that are served faster than a threshold.",
        events={
            "account_id": "12345678",
            "valid_events": {
                "from_": "Transaction",
                "where": "appName = 'Example application' AND (transactionType='Web')",
            },
            "bad_events": {
                "from_": "Transaction",
                "where": "appName = 'Example application' AND (transactionType= 'Web') AND duration > 0.1",
            },
        },
        objective={
            "target": foo_target,
            "time_window": {
                "rolling": {
                    "count": foo_period,
                    "unit": "DAY",
                },
            },
        })
    ```
    Then use the helper to obtain the necessary fields to set up an alert on that Service Level.
    Note that the Service Level was set up using bad events, that's why `is_bad_events` is set to `true`.
    If the Service Level was configured with good events that would be unnecessary as the field defaults to `false`.

    Here is an example of a `slow_burn` alert.

    ```python
    import pulumi
    import pulumi_newrelic as newrelic

    foo_slow_burn = newrelic.get_service_level_alert_helper(alert_type="slow_burn",
        sli_guid=foo["sliGuid"],
        slo_target=foo_target,
        slo_period=foo_period,
        is_bad_events=True)
    your_condition = newrelic.NrqlAlertCondition("your_condition",
        account_id="12345678",
        policy_id="67890",
        type="static",
        name="Slow burn alert",
        enabled=True,
        violation_time_limit_seconds=259200,
        nrql={
            "query": foo_slow_burn.nrql,
        },
        critical={
            "operator": "above_or_equals",
            "threshold": foo_slow_burn.threshold,
            "threshold_duration": 900,
            "threshold_occurrences": "at_least_once",
        },
        fill_option="none",
        aggregation_window=foo_slow_burn.evaluation_period,
        aggregation_method="event_flow",
        aggregation_delay="120",
        slide_by=900)
    ```

    Here is an example of a custom alert:

    ```python
    import pulumi
    import pulumi_newrelic as newrelic

    foo_custom = newrelic.get_service_level_alert_helper(alert_type="custom",
        sli_guid=foo["sliGuid"],
        slo_target=foo_target,
        slo_period=foo_period,
        custom_tolerated_budget_consumption=4,
        custom_evaluation_period=5400,
        is_bad_events=True)
    your_condition = newrelic.NrqlAlertCondition("your_condition",
        account_id="12345678",
        policy_id="67890",
        type="static",
        name="Custom burn alert",
        enabled=True,
        violation_time_limit_seconds=259200,
        nrql={
            "query": foo_custom.nrql,
        },
        critical={
            "operator": "above_or_equals",
            "threshold": foo_custom.threshold,
            "threshold_duration": 900,
            "threshold_occurrences": "at_least_once",
        },
        fill_option="none",
        aggregation_window=foo_custom.evaluation_period,
        aggregation_method="event_flow",
        aggregation_delay="120",
        slide_by=60)
    ```


    :param builtins.str alert_type: The type of alert we want to set. Valid values are:
    :param builtins.int custom_evaluation_period: Aggregation window taken into consideration in seconds. Mandatory if `alert_type` is `custom`.
    :param builtins.float custom_tolerated_budget_consumption: How much budget you tolerate to consume during the custom evaluation period, valid values between `0` and `100`. Mandatory if `alert_type` is `custom`.
    :param builtins.bool is_bad_events: If the SLI is defined using bad events. Defaults to `false`
    :param builtins.str sli_guid: The guid of the sli we want to set the alert on.
    :param builtins.int slo_period: The time window of the Service Level Objective in days. Valid values are `1`, `7` and `28`.
    :param builtins.float slo_target: The target of the Service Level Objective, valid values between `0` and `100`.
    """
    __args__ = dict()
    __args__['alertType'] = alert_type
    __args__['customEvaluationPeriod'] = custom_evaluation_period
    __args__['customToleratedBudgetConsumption'] = custom_tolerated_budget_consumption
    __args__['isBadEvents'] = is_bad_events
    __args__['sliGuid'] = sli_guid
    __args__['sloPeriod'] = slo_period
    __args__['sloTarget'] = slo_target
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('newrelic:index/getServiceLevelAlertHelper:getServiceLevelAlertHelper', __args__, opts=opts, typ=GetServiceLevelAlertHelperResult)
    return __ret__.apply(lambda __response__: GetServiceLevelAlertHelperResult(
        alert_type=pulumi.get(__response__, 'alert_type'),
        custom_evaluation_period=pulumi.get(__response__, 'custom_evaluation_period'),
        custom_tolerated_budget_consumption=pulumi.get(__response__, 'custom_tolerated_budget_consumption'),
        evaluation_period=pulumi.get(__response__, 'evaluation_period'),
        id=pulumi.get(__response__, 'id'),
        is_bad_events=pulumi.get(__response__, 'is_bad_events'),
        nrql=pulumi.get(__response__, 'nrql'),
        sli_guid=pulumi.get(__response__, 'sli_guid'),
        slo_period=pulumi.get(__response__, 'slo_period'),
        slo_target=pulumi.get(__response__, 'slo_target'),
        threshold=pulumi.get(__response__, 'threshold'),
        tolerated_budget_consumption=pulumi.get(__response__, 'tolerated_budget_consumption')))
